Description Usage
View source: R/insertPlusEnterAddin.R
Call this function as an addin to insert + at the cursor position and go to new line.
+
1
insertPlusEnterAddin()
Add the following code to your website.
REMOVE THIS Copy to clipboard
For more information on customizing the embed code, read Embedding Snippets.